% This experiment testing the effect of inner-distance shape context
% on the articulated shape database containing 25 objects. The result and the original shape 
% data are located at directory 'data/'
% 
% For details, please refer to
% 	H. Ling and D.W. Jacobs. Shape Classification Using the Inner-Distance, IEEE Trans on Pattern Anal. and Mach. Intell. (PAMI), 29(2):286-299, 2007. 
%
% Haibin Ling (hbling AT umiacs.umd.edu)
%	Computer Science Department, University of Maryland, College park

clear;
addpath common_innerdist;

ifig		= -1;
sdir		='train/';
test_dir    ='test/';


%------ Parameters ----------------------------------------------
n_class		= 2;
n_obj		= 100;
n_objall	= n_obj*n_class;

test_n_class = 2;
test_n_obj = 100;
%-- shape context parameters
n_dist		= 5;
n_theta		= 12;
bTangent	= 1;
bSmoothCont	= 1;
n_contsamp	= 200;
b_simplecont= 1;

%-- FILEs --------------------------------------------
%-- Training-----------------------
sDisAngSamp	= ['_' i2s(n_dist,2) 'x' i2s(n_theta,2) 'x' i2s(n_contsamp,3)];
sCont		= [sdir 'articu_cont_' i2s(n_contsamp) '.mat'];
s_articu_sc	= [sdir 'IDSC' sDisAngSamp '.mat'];

%-- Testing -----------------------
test_DisAngSamp	= ['_' i2s(n_dist,2) 'x' i2s(n_theta,2) 'x' i2s(n_contsamp,3)];
test_Cont		= [test_dir 'test_articu_cont_' i2s(n_contsamp) '.mat'];
t_articu_sc	= [test_dir 'IDSC' test_DisAngSamp '.mat'];


%fprintf('%s,\n\n', sDisAngSamp);


%-- Extract contours -------------------------------------------------------------
%-- Training -----------------------------
if 1
	[articu_cont] = batch_contour_f(sdir,n_class,n_obj);
	[articu_cont] = batch_contour_f(sdir,n_class,n_obj,n_contsamp);
else
        load(sCont);
end
%-- Testing ------------------------------
if 1
	[test_articu_cont] = test_contour_f(test_dir,test_n_class,test_n_obj);
	[test_articu_cont] = test_contour_f(test_dir,test_n_class,test_n_obj,n_contsamp);
else
    load(test_Cont);
end

%-- Compute or Load all the shape context data ------------------------------------
%-- Training ------------------------------------------------
if 1
	[articu_sc] = batch_comp_articu_sc(sdir,sCont,n_dist, n_theta, bTangent, bSmoothCont,n_class,n_obj,b_simplecont);
	save(s_articu_sc, 'articu_sc');
else
    load(s_articu_sc);
end
%-- Testing -------------------------------------------------
if 1
	[test_articu_sc] = test_comp_articu_sc(test_dir,test_Cont,n_dist, n_theta, bTangent, bSmoothCont,test_n_class,test_n_obj,b_simplecont);
	save(t_articu_sc, 'test_articu_sc');
else
    load(t_articu_sc);
end

%-- SVM Classification ----------------------------
svmModels = cell(1,10);
[articu_sc_array] = getSlopes(articu_cont,articu_sc);

for i=1:10
    sc = articu_sc_array{i};
    svmModels{i} = get_svmModel(sc);
end

[classes,cp] = svm_classify(svmModels, test_articu_cont, test_articu_sc);

for i=1:2*n_obj
    fprintf('%d class=%d\n',i,classes(i));
end

%-- get accuracy ---------
cp.CorrectRate
cp.CountingMatrix

%-- get confusion matrix ------
%cp.CountingMatrix
%fprintf('%d\n',class);
%if class==1
%    fprintf('closed\n');
%else
%    fprintf('open\n');
%end

return;